@@ -22,12 +22,12 @@
 #include <tqdict.h>
 
 #include "kiledebug.h"
-#include <klocale.h>
-#include <kglobal.h>
+#include <tdelocale.h>
+#include <tdeglobal.h>
 #include <kstandarddirs.h>
-#include <kconfig.h>
-#include <kmessagebox.h>
-#include <ktexteditor/codecompletioninterface.h>
+#include <tdeconfig.h>
+#include <tdemessagebox.h>
+#include <tdetexteditor/codecompletioninterface.h>
 
 #include "kileinfo.h"
 #include "kileviewmanager.h"
@@ -149,7 +149,7 @@ namespace KileDocument
 
 	//////////////////// configuration ////////////////////
 
-	void CodeCompletion::readConfig(KConfig *config)
+	void CodeCompletion::readConfig(TDEConfig *config)
 	{
 		KILE_DEBUG() << "=== CodeCompletion::readConfig ===================" << endl;
 
@@ -197,7 +197,7 @@ namespace KileDocument
 		}
 	}
 
-	void CodeCompletion::readKateConfigFlags(KConfig *config)
+	void CodeCompletion::readKateConfigFlags(TDEConfig *config)
 	{
 		config->setGroup("Kate Document Defaults");
 		m_autobrackets = ( config->readNumEntry("Basic Config Flags",0) & cfAutoBrackets );
@@ -892,7 +892,7 @@ namespace KileDocument
 	void CodeCompletion::readWordlist( TQStringList &wordlist, const TQString &filename, bool global )
 	{
 		TQString file = ( global )
-		             ? KGlobal::dirs()->findResource( "appdata", "complete/" + filename )
+		             ? TDEGlobal::dirs()->findResource( "appdata", "complete/" + filename )
 		             : m_localAbbrevFile;
 		if ( file.isEmpty() ) return;
 
@@ -1153,7 +1153,7 @@ namespace KileDocument
 
 	void CodeCompletion::slotCharactersInserted(int, int, const TQString& string )
 	{
-		KILE_DEBUG() << "==slotCharactersInserted (" << m_kilecompletion << "," << m_inprogress << ", " << m_ref << ", " << string << ")=============" << endl;
+		KILE_DEBUG() << "==slotCharactersInserted (m_kilecompletion=" << m_kilecompletion << "m_inprogress," << m_inprogress << ",m_ref=" << m_ref << ",string=" << string << ")=============" << endl;
 
 		if ( !inProgress() && m_autoDollar && string=="$" )
 		{
@@ -1184,6 +1184,16 @@ namespace KileDocument
 				editCompleteList(reftype,startpattern);
 				return;
 			}
+		} // also unusual but may also happen, 20.11.2008 tbraun
+		else if( m_ref && !inProgress())
+		{
+			TQString startpattern;
+			CodeCompletion::Type reftype = insideReference(startpattern);
+			if ( reftype == CodeCompletion::ctNone )
+			{
+				m_ref = false;
+				return;
+			}
 		}
 
 		TQString word;
