@@ -68,13 +68,13 @@
 #include <tqregexp.h>
 #include <tqdatetime.h>
 
-#include <kio/netaccess.h>
-#include <kconfig.h>
-#include <klocale.h>
-#include <kapplication.h>
+#include <tdeio/netaccess.h>
+#include <tdeconfig.h>
+#include <tdelocale.h>
+#include <tdeapplication.h>
 #include "kiledebug.h"
 #include <kiconloader.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 #include <kinputdialog.h>
 
 #include "codecompletion.h"
@@ -112,7 +112,7 @@ KURL Info::repairInvalidCharacters(const KURL& url, bool checkForFileExistence /
 KURL Info::renameIfExist(const KURL& url)
 {
 	KURL ret(url);
-	while ( KIO::NetAccess::exists(url, true, kapp->mainWidget()) ) // check for writing possibility
+	while ( TDEIO::NetAccess::exists(url, true, kapp->mainWidget()) ) // check for writing possibility
 	{
 		bool isOK;
 		TQString newURL = KInputDialog::getText(
@@ -480,7 +480,23 @@ const long* TextInfo::getStatistics()
 	/* [0] = #c in words, [1] = #c in latex commands and environments,
 	   [2] = #c whitespace, [3] = #words, [4] = # latex_commands, [5] = latex_environments */
 	m_arStatistics[0]=m_arStatistics[1]=m_arStatistics[2]=m_arStatistics[3]=m_arStatistics[4]=m_arStatistics[5]=0;
+	TQString line;
 
+	if ( m_doc && m_doc->hasSelection() )
+	{
+		line = m_doc->selection();
+		KILE_DEBUG() << "getStat : line : " << line << endl;
+		count(line, m_arStatistics);
+	}
+	else if (m_doc)
+	{
+		for (uint l=0; l < m_doc->numLines(); ++l)
+		{
+			line = m_doc->textLine(l);
+			KILE_DEBUG() << "getStat : line : " << line << endl;
+			count(line, m_arStatistics);
+		}
+	}
 	return m_arStatistics;
 }
 
@@ -692,29 +708,6 @@ LaTeXInfo::~LaTeXInfo()
 {
 }
 
-const long* LaTeXInfo::getStatistics()
-{
-	/* [0] = #c in words, [1] = #c in latex commands and environments,
-	   [2] = #c whitespace, [3] = #words, [4] = # latex_commands, [5] = latex_environments */
-	m_arStatistics[0]=m_arStatistics[1]=m_arStatistics[2]=m_arStatistics[3]=m_arStatistics[4]=m_arStatistics[5]=0;
-	TQString line;
-
-	if ( m_doc && m_doc->hasSelection() )
-	{
-		line = m_doc->selection();
-		KILE_DEBUG() << "getStat : line : " << line << endl;
-		count(line, m_arStatistics);
-	}
-	else if (m_doc)
-	for (uint l=0; l < m_doc->numLines(); ++l)
-	{
-		line = m_doc->textLine(l);
-		KILE_DEBUG() << "getStat : line : " << line << endl;
-		count(line, m_arStatistics);
-	}
-	return m_arStatistics;
-}
-
 Type LaTeXInfo::getType()
 {
 	return LaTeX;
