@@ -32,13 +32,13 @@
 #include <tqregexp.h>
 #include <tqvalidator.h>
 
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
 #include <kurlcompletion.h>
-#include <kfiledialog.h>
+#include <tdefiledialog.h>
 #include <kcombobox.h>
 #include "kiledebug.h"
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <kiconloader.h>
 
 #include "kileproject.h"
@@ -220,7 +220,7 @@ KileNewProjectDlg::KileNewProjectDlg(KileTemplate::Manager *templateManager, Kil
 	TQWhatsThis::add(m_location, whatsthisPath);
 	lb1->setBuddy(m_location);
 	m_pbChooseDir= new KPushButton(i18n("Select Folder..."), m_pgroup, "dirchooser_button" );
-	m_pbChooseDir->setPixmap( SmallIcon("fileopen") );
+	m_pbChooseDir->setPixmap( SmallIcon("document-open") );
 	int wpixmap = m_pbChooseDir->pixmap()->width();
 	m_pbChooseDir->setFixedWidth(wpixmap+10);
 	m_pbChooseDir->setFixedHeight(wpixmap+10);
