@@ -64,15 +64,15 @@
 #include <tqregexp.h>
 #include <tqclipboard.h>
  
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include "kiledebug.h"
-#include <kmessagebox.h>
-#include <klocale.h>
+#include <tdemessagebox.h>
+#include <tdelocale.h>
 #include <kiconloader.h>
 #include <kurl.h>
 #include <krun.h>
 #include <kmimetype.h>
-#include <ktexteditor/markinterface.h>
+#include <tdetexteditor/markinterface.h>
 
 #include "kileinfo.h"
 #include "kiledocmanager.h"
@@ -82,7 +82,7 @@
 ////////////////////// KileListViewItem with all info //////////////////////
 
 KileListViewItem::KileListViewItem(TQListViewItem * parent, TQListViewItem * after, const TQString &title, const KURL &url, uint line, uint column, int type, int level, uint startline, uint startcol) : 
-	KListViewItem(parent,after),
+	TDEListViewItem(parent,after),
 	m_title(title), m_url(url), m_line(line), m_column(column), m_type(type), m_level(level),
 	m_startline(startline), m_startcol(startcol)
 {
@@ -90,12 +90,12 @@ KileListViewItem::KileListViewItem(TQListViewItem * parent, TQListViewItem * aft
 }
 
 KileListViewItem::KileListViewItem(TQListView * parent, const TQString & label) : 
-	KListViewItem(parent,label),
+	TDEListViewItem(parent,label),
 	m_title(label), m_url(KURL()), m_line(0),  m_column(0), m_type(KileStruct::None), m_level(0) 
 {}
 
 KileListViewItem::KileListViewItem(TQListViewItem * parent, const TQString & label) :
-	KListViewItem(parent,label),
+	TDEListViewItem(parent,label),
 	m_title(label), m_url(KURL()), m_line(0),  m_column(0), m_type(KileStruct::None), m_level(0) 
 {}
 
@@ -112,7 +112,7 @@ void KileListViewItem::setItemEntry()
 
 ////////////////////// introduce a new ToolTip //////////////////////
 
-KileListViewToolTip::KileListViewToolTip(KListView *listview) : TQToolTip(listview->viewport()), m_listview(listview) 
+KileListViewToolTip::KileListViewToolTip(TDEListView *listview) : TQToolTip(listview->viewport()), m_listview(listview) 
 {}
 
 void KileListViewToolTip::maybeTip(const TQPoint &p) 
@@ -145,7 +145,7 @@ namespace KileWidget
 	////////////////////// StructureList listview //////////////////////
 	
 	StructureList::StructureList(Structure *stack, KileDocument::Info *docinfo) : 
-		KListView(stack),
+		TDEListView(stack),
 		m_stack(stack), m_docinfo(docinfo)
 	{
 		show();
@@ -161,7 +161,7 @@ namespace KileWidget
 		
 		//connect(this, TQT_SIGNAL(clicked(TQListViewItem *)), m_stack, TQT_SLOT(slotClicked(TQListViewItem *)));
 		connect(this, TQT_SIGNAL(doubleClicked(TQListViewItem *)), m_stack, TQT_SLOT(slotDoubleClicked(TQListViewItem *)));
-		connect(this, TQT_SIGNAL(contextMenu(KListView *, TQListViewItem *, const TQPoint & )), m_stack, TQT_SLOT(slotPopup(KListView *, TQListViewItem * , const TQPoint & )));
+		connect(this, TQT_SIGNAL(contextMenu(TDEListView *, TQListViewItem *, const TQPoint & )), m_stack, TQT_SLOT(slotPopup(TDEListView *, TQListViewItem * , const TQPoint & )));
 		
 		connect(this, TQT_SIGNAL(executed(TQListViewItem*)), m_stack, TQT_SLOT(slotClicked(TQListViewItem*)));
 		connect(m_stack, TQT_SIGNAL(configChanged()), this, TQT_SLOT(slotConfigChanged()));
@@ -336,7 +336,7 @@ namespace KileWidget
 		else if ( folder == "refs" )
 		{
 			fldr->setText(0, i18n("Undefined References"));
-			fldr->setPixmap(0, SmallIcon("stop"));
+			fldr->setPixmap(0, SmallIcon("process-stop"));
 		}
 		else if ( folder == "todo" )
 		{
@@ -611,7 +611,7 @@ namespace KileWidget
 		m_default = new StructureList(this, 0L);
 		m_default->activate();
 	
-		m_popup = new KPopupMenu(this, "structureview_popup");
+		m_popup = new TDEPopupMenu(this, "structureview_popup");
 	}
 
 	Structure::~Structure()
@@ -697,27 +697,28 @@ namespace KileWidget
 				else
 					emit(fileOpen(url, TQString()));
 			}
-			else if( item->type() == KileStruct::Bibliography ){
-				fname = m_ki->checkOtherPaths(fi.dirPath(),fi.fileName(),KileInfo::bibinputs);
-				fi.setFile(fname);
-				url.setPath(fname);
-				if(fi.isReadable()){
-					emit(fileOpen(url, TQString()));
-				}
-			}
-			else if( item->type() == KileStruct::Input ){
-				fname = m_ki->checkOtherPaths(fi.dirPath(),fi.fileName(),KileInfo::texinputs);
-				fi.setFile(fname);
-				url.setPath(fname);
-				if(fi.isReadable()){
-					emit(fileOpen(url, TQString()));
-				}
-			}
 			else{
-				if ( KMessageBox::warningYesNo(this, i18n("Cannot find the included file. The file does not exist, is not readable or Kile is unable to determine the correct path to it. The filename causing this error was: %1.\nDo you want to create this file?").arg(fname), i18n("Cannot Find File"))
-			== KMessageBox::Yes)
-				{
-					emit(fileNew(url));
+				TQString otherFilename;
+
+				if( item->type() == KileStruct::Bibliography ){
+					otherFilename = m_ki->checkOtherPaths(fi.dirPath(),fi.fileName(),KileInfo::bibinputs);
+				}
+				else if( item->type() == KileStruct::Input ){
+					otherFilename = m_ki->checkOtherPaths(fi.dirPath(),fi.fileName(),KileInfo::texinputs);
+				}
+
+				fi.setFile(otherFilename);
+
+				if(fi.isReadable()){
+					url.setPath(otherFilename);
+					emit(fileOpen(url, TQString()));
+				}
+				else{
+					if ( KMessageBox::warningYesNo(this, i18n("Cannot find the included file. The file does not exist, is not readable or Kile is unable to determine the correct path to it. The filename causing this error was: %1.\nDo you want to create this file?").arg(fname), i18n("Cannot Find File"))
+				== KMessageBox::Yes) {
+						url.setPath(fname);
+						emit(fileNew(url));
+					}
 				}
 			}
 		}
@@ -728,7 +729,7 @@ namespace KileWidget
 	//  - sectioning: 10 - 16
 	//  - graphics:   100ff
 
-	void Structure::slotPopup(KListView *, TQListViewItem *itm, const TQPoint &point)
+	void Structure::slotPopup(TDEListView *, TQListViewItem *itm, const TQPoint &point)
 	{
 		KILE_DEBUG() << "\tStructure::slotPopup" << endl;
 		
@@ -771,7 +772,7 @@ namespace KileWidget
 				KURL url;
 				url.setPath(m_popupInfo);
 				
-				m_offerList = KTrader::self()->query(KMimeType::findByURL(url)->name(), "Type == 'Application'");
+				m_offerList = TDETrader::self()->query(KMimeType::findByURL(url)->name(), "Type == 'Application'");
 				for (uint i=0; i < m_offerList.count(); ++i)
 				{
 					m_popup->insertItem(SmallIcon(m_offerList[i]->icon()), m_offerList[i]->name(), i+SectioningGraphicsOfferlist);
