@@ -23,18 +23,18 @@
 #include <tqpixmap.h>
 #include <tqclipboard.h>
 
-#include <kdeversion.h>
-#include <kglobal.h>
+#include <tdeversion.h>
+#include <tdeglobal.h>
 #include <kate/view.h>
 #include <kate/document.h>
-#include <kparts/componentfactory.h>
+#include <tdeparts/componentfactory.h>
 #include <kxmlguiclient.h>
 #include <kxmlguifactory.h>
 #include <kiconloader.h>
 #include <kmimetype.h>
-#include <klocale.h>
-#include <ktexteditor/editinterfaceext.h>
-#include <kapplication.h>
+#include <tdelocale.h>
+#include <tdetexteditor/editinterfaceext.h>
+#include <tdeapplication.h>
 #include <kurldrag.h>
 
 #include "editorkeysequencemanager.h"
@@ -74,13 +74,13 @@ void Manager::setClient(TQObject *receiver, KXMLGUIClient *client)
 	m_receiver = receiver;
 	m_client = client;
 	if(NULL == m_client->actionCollection()->action("popup_pasteaslatex"))
-		new KAction(i18n("Paste as LaTe&X"), 0, this,
+		new TDEAction(i18n("Paste as LaTe&X"), 0, this,
 			TQT_SLOT(pasteAsLaTeX()), m_client->actionCollection(), "popup_pasteaslatex");
 	if(NULL == m_client->actionCollection()->action("popup_converttolatex"))
-		new KAction(i18n("Convert Selection to &LaTeX"), 0, this,
+		new TDEAction(i18n("Convert Selection to &LaTeX"), 0, this,
 			TQT_SLOT(convertSelectionToLaTeX()), m_client->actionCollection(), "popup_converttolatex");
 	if(NULL == m_client->actionCollection()->action("popup_quickpreview"))
-		new KAction(i18n("&QuickPreview Selection"), 0, this,
+		new TDEAction(i18n("&QuickPreview Selection"), 0, this,
 			TQT_SLOT(quickPreviewPopup()), m_client->actionCollection(), "popup_quickpreview");
 }
 
@@ -133,7 +133,7 @@ Kate::View* Manager::createTextView(KileDocument::TextInfo *info, int index)
 
 	//insert the view in the tab widget
 	m_tabs->insertTab( view, m_ki->getShortName(doc), index );
-	#if KDE_VERSION >= KDE_MAKE_VERSION(3,4,0)
+	#if TDE_VERSION >= TDE_MAKE_VERSION(3,4,0)
 		m_tabs->setTabToolTip(view, doc->url().pathOrURL() );
 	#else
 		m_tabs->setTabToolTip(view, doc->url().prettyURL() );
@@ -153,7 +153,7 @@ Kate::View* Manager::createTextView(KileDocument::TextInfo *info, int index)
 	connect( view, TQT_SIGNAL(filterInsertString(KTextEditor::CompletionEntry*,TQString *)), m_ki->editorExtension()->complete(),  TQT_SLOT(slotFilterCompletion(KTextEditor::CompletionEntry*,TQString *)) );
 
 	// install a working kate part popup dialog thingy
-	TQPopupMenu *viewPopupMenu = (TQPopupMenu*)(m_client->factory()->container("ktexteditor_popup", m_client));
+	TQPopupMenu *viewPopupMenu = (TQPopupMenu*)(m_client->factory()->container("tdetexteditor_popup", m_client));
 	if((NULL != view) && (NULL != viewPopupMenu))
 		view->installPopup(viewPopupMenu);
 	if(NULL != viewPopupMenu)
@@ -172,7 +172,7 @@ Kate::View* Manager::createTextView(KileDocument::TextInfo *info, int index)
 	unplugKatePartMenu(view);
 
 	// use Kile's save and save-as functions instead of Katepart's
-	KAction *action = view->actionCollection()->action(KStdAction::stdName(KStdAction::Save)); 
+	TDEAction *action = view->actionCollection()->action(KStdAction::stdName(KStdAction::Save)); 
 	if ( action ) 
 	{
 		KILE_DEBUG() << "   reconnect action 'file_save'..." << endl;
@@ -308,15 +308,15 @@ void Manager::reflectDocumentStatus(Kate::Document *doc, bool isModified, unsign
 {
 	TQPixmap icon;
 	if ( reason == 0 && isModified ) //nothing
-		icon = SmallIcon("filesave");
+		icon = SmallIcon("document-save");
 	else if ( reason == 1 || reason == 2 ) //dirty file
-		icon = SmallIcon("revert");
+		icon = SmallIcon("document-revert");
 	else if ( reason == 3 ) //file deleted
-		icon = SmallIcon("stop");
+		icon = SmallIcon("process-stop");
 	else if ( m_ki->extensions()->isScriptFile(doc->url()) )
 		icon = SmallIcon("js");
 	else
-		icon = KMimeType::pixmapForURL (doc->url(), 0, KIcon::Small);
+		icon = KMimeType::pixmapForURL (doc->url(), 0, TDEIcon::Small);
 
 	changeTab(doc->views().first(), icon, m_ki->getShortName(doc));
 }
@@ -330,12 +330,12 @@ void Manager::onKatePopupMenuRequest(void)
 	if(NULL == view)
 		return;
 
-	TQPopupMenu *viewPopupMenu = (TQPopupMenu*)(m_client->factory()->container("ktexteditor_popup", m_client));
+	TQPopupMenu *viewPopupMenu = (TQPopupMenu*)(m_client->factory()->container("tdetexteditor_popup", m_client));
 	if(NULL == viewPopupMenu)
 		return;
 
 	// Setting up the "QuickPreview selection" entry
-	KAction *quickPreviewAction = m_client->actionCollection()->action("popup_quickpreview");
+	TDEAction *quickPreviewAction = m_client->actionCollection()->action("popup_quickpreview");
 	if(NULL != quickPreviewAction) {
 		if(!quickPreviewAction->isPlugged())
 			quickPreviewAction->plug(viewPopupMenu);
@@ -347,7 +347,7 @@ void Manager::onKatePopupMenuRequest(void)
 	}
 
 	// Setting up the "Convert to LaTeX" entry
-	KAction *latexCvtAction = m_client->actionCollection()->action("popup_converttolatex");
+	TDEAction *latexCvtAction = m_client->actionCollection()->action("popup_converttolatex");
 	if(NULL != latexCvtAction) {
 		if(!latexCvtAction->isPlugged())
 			latexCvtAction->plug(viewPopupMenu);
@@ -356,12 +356,12 @@ void Manager::onKatePopupMenuRequest(void)
 	}
 
 	// Setting up the "Paste as LaTeX" entry
-	KAction *pasteAsLaTeXAction = m_client->actionCollection()->action("popup_pasteaslatex");
+	TDEAction *pasteAsLaTeXAction = m_client->actionCollection()->action("popup_pasteaslatex");
 	if((NULL != pasteAsLaTeXAction)) {
 		if(!pasteAsLaTeXAction->isPlugged())
 			pasteAsLaTeXAction->plug(viewPopupMenu);
 
-		TQClipboard *clip = KApplication::clipboard();
+		TQClipboard *clip = TDEApplication::clipboard();
 		if(NULL != clip)
 			pasteAsLaTeXAction->setEnabled(!clip->text().isNull());
 	}
@@ -464,7 +464,7 @@ void Manager::pasteAsLaTeX(void)
 		doc->removeSelectedText();
 
 	PlainToLaTeXConverter cvt;
-	TQString toPaste = cvt.ConvertToLaTeX(KApplication::clipboard()->text());
+	TQString toPaste = cvt.ConvertToLaTeX(TDEApplication::clipboard()->text());
 	doc->insertText(cursorLine, cursorCol, toPaste);
 
 	// End of the "atomic edit operation"
@@ -569,11 +569,11 @@ void Manager::unplugKatePartMenu(Kate::View* view)
 
 		for ( uint i=0; i < actionlist.count(); ++i )
 		{
-			KAction *action = view->actionCollection()->action( actionlist[i].ascii() ); 
+			TDEAction *action = view->actionCollection()->action( actionlist[i].ascii() ); 
 			if ( action ) 
 			{
 				action->unplugAll();
-//				action->setShortcut(KShortcut());
+//				action->setShortcut(TDEShortcut());
 			}
 		}
 	}
